cellsPerSelectionGroup: Get the number of cells in each selection group

View source: R/pagodaWebSelections.R

cellsPerSelectionGroupR Documentation

Get the number of cells in each selection group

Description

Get the number of cells in each selection group

Usage

cellsPerSelectionGroup(selection)

Arguments

selection

a pagoda2 selection list

Value

a named vector of cell numbers in each groups


pagoda2 documentation built on March 9, 2026, 1:06 a.m.