factorToP2selection: Converts a names factor to a p2 selection object if colors...

View source: R/pagodaWebSelections.R

factorToP2selectionR Documentation

Converts a names factor to a p2 selection object if colors are provided it assigns those, otherwise uses a rainbow palette

Description

Converts a names factor to a p2 selection object if colors are provided it assigns those, otherwise uses a rainbow palette

Usage

factorToP2selection(cl, col = NULL)

Arguments

cl

factor

col

names vector of colors (default=NULL)

Value

a p2 selection object (list)


pagoda2 documentation built on March 9, 2026, 1:06 a.m.