getIntExtNamesP2Selection: Get a mapping form internal to external names for the...

View source: R/pagodaWebSelections.R

getIntExtNamesP2SelectionR Documentation

Get a mapping form internal to external names for the specified selection object

Description

Get a mapping form internal to external names for the specified selection object

Usage

getIntExtNamesP2Selection(x)

Arguments

x

p2 selection object

Value

list of names from the specified selection object


pagoda2 documentation built on March 9, 2026, 1:06 a.m.