plotMulticlassified: Plot multiclassified cells per selection as a percent barplot

View source: R/pagodaWebSelections.R

plotMulticlassifiedR Documentation

Plot multiclassified cells per selection as a percent barplot

Description

Plot multiclassified cells per selection as a percent barplot

Usage

plotMulticlassified(sel)

Arguments

sel

pagoda2 selection object

Value

ggplot2 object


pagoda2 documentation built on March 9, 2026, 1:06 a.m.